@@ -5,7 +5,7 @@ package CXC::Number;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 #
 # This file is part of CXC-Number
@@ -31,7 +31,7 @@ CXC::Number - A namespace for modules which deal with numbers.
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 DESCRIPTION
 
@@ -54,9 +54,8 @@ constructed so that they are useful for binning data.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number-Sequence> or
-by email to
-L<bug-cxc-number-sequence@rt.cpan.org|mailto:bug-cxc-number-sequence@rt.cpan.org>.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
+to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
