@@ -25,7 +25,7 @@ use Moo;
 use experimental 'signatures';
 use experimental 'refaliasing';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Exporter::Shiny qw( join_n overlay_n );
 
@@ -1025,7 +1025,7 @@ CXC::Number::Grid - A class representing a one dimensional numeric grid
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -1440,9 +1440,8 @@ After:
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number-Sequence> or
-by email to
-L<bug-cxc-number-sequence@rt.cpan.org|mailto:bug-cxc-number-sequence@rt.cpan.org>.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
+to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
