@@ -6,7 +6,7 @@ use feature ':5.24';
 
 use Moo::Role;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use experimental 'signatures';
 use namespace::clean;
@@ -43,7 +43,7 @@ CXC::Number::Grid::Role::BigNum - Role to return Math::BigFloats
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -58,9 +58,8 @@ passed L<Math::BigFloat> arrays and scalars.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number-Sequence> or
-by email to
-L<bug-cxc-number-sequence@rt.cpan.org|mailto:bug-cxc-number-sequence@rt.cpan.org>.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
+to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
