@@ -5,7 +5,7 @@ package CXC::Number::Grid::Types;
 use strict;
 use warnings;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use Math::BigInt upgrade => 'Math::BigFloat';
 use Math::BigFloat;
@@ -65,7 +65,7 @@ CXC::Number::Grid::Types - Type::Tiny types for CXC::Number::Grid
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 TYPES
 
@@ -76,9 +76,8 @@ A array of numbers with at lest two members which is sorted by increasing value
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number-Sequence> or
-by email to
-L<bug-cxc-number-sequence@rt.cpan.org|mailto:bug-cxc-number-sequence@rt.cpan.org>.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
+to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
