@@ -16,7 +16,7 @@ use Moo;
 
 use experimental 'signatures';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use namespace::clean;
 
@@ -196,7 +196,7 @@ CXC::Number::Sequence - Numerical Sequence Generation
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -294,9 +294,8 @@ Returns an object which returns piddles for the following methods
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number-Sequence> or
-by email to
-L<bug-cxc-number-sequence@rt.cpan.org|mailto:bug-cxc-number-sequence@rt.cpan.org>.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
+to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
