@@ -8,7 +8,7 @@ use warnings;
 use parent 'Exporter::Tiny';
 use custom::failures ();
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 our @EXPORT_OK;
 BEGIN {
@@ -45,14 +45,13 @@ CXC::Number::Sequence::Failure - CXC::Number::Sequence Exceptions
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number-Sequence> or
-by email to
-L<bug-cxc-number-sequence@rt.cpan.org|mailto:bug-cxc-number-sequence@rt.cpan.org>.
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=CXC-Number> or by email
+to L<bug-cxc-number@rt.cpan.org|mailto:bug-cxc-number@rt.cpan.org>.
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
